/*
 * Copyright (c) 2002-2008 TeamDev Ltd. All rights reserved.
 *
 * Use is subject to license terms.
 *
 * The complete licence text can be found at
 * http://www.teamdev.com/winpack/license.jsf
 */
package teamdev.jxcapture.samples.demo;

import com.apple.eawt.Application;
import com.apple.eawt.ApplicationAdapter;
import com.apple.eawt.ApplicationEvent;

import javax.swing.*;

/**
 * @author Ikryanov Vladimir
 */
public class ApplicationWindow extends JFrame {

    public ApplicationWindow(JxCaptureDemo application) {
        createMenuBar();
        initSystemMenu(application);
        setUndecorated(true);
        setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
    }

    private void createMenuBar() {
        Actions.ObjectCaptureAction objectCapture =
                new Actions.ObjectCaptureAction(TrayPopupMenu.class, Actions.ActionType.MENU);
        Actions.RegionCaptureAction regionCapture =
                new Actions.RegionCaptureAction(TrayPopupMenu.class, Actions.ActionType.MENU);
        Actions.DesktopCaptureAction desktopCapture =
                new Actions.DesktopCaptureAction(TrayPopupMenu.class, Actions.ActionType.MENU);
        Actions.ActiveWindowCaptureAction windowCapture =
                new Actions.ActiveWindowCaptureAction(TrayPopupMenu.class, Actions.ActionType.MENU);

        JMenuItem activeWindowItem = new JMenuItem(windowCapture);
        JMenuItem objectItem = new JMenuItem(objectCapture);
        JMenuItem regionItem = new JMenuItem(regionCapture);
        JMenuItem desktopItem = new JMenuItem(desktopCapture);
        JMenuItem toViewerItem = new JRadioButtonMenuItem(new Actions.CaptureToViewerAction(TrayPopupMenu.class));
        JMenuItem toClipboardItem = new JRadioButtonMenuItem(new Actions.CaptureToClipboardAction(TrayPopupMenu.class));
        JMenuItem toFileItem = new JRadioButtonMenuItem(new Actions.CaptureToFileAction(TrayPopupMenu.class));

        ApplicationSettings settings = ApplicationSettings.getInstance();
        toViewerItem.setSelected(settings.isCaptureToViewer());
        toFileItem.setSelected(settings.isCaptureToFile());
        toClipboardItem.setSelected(settings.isCaptureToClipboard());

        ButtonGroup group = new ButtonGroup();
        group.add(toViewerItem);
        group.add(toFileItem);
        group.add(toClipboardItem);

        JMenu captureMenu = new JMenu("Capture");
        captureMenu.add(desktopItem);
        captureMenu.add(activeWindowItem);
        captureMenu.add(objectItem);
        captureMenu.add(regionItem);
        captureMenu.addSeparator();
        captureMenu.add(toViewerItem);
        captureMenu.add(toClipboardItem);
        captureMenu.add(toFileItem);

        JMenuBar menuBar = new JMenuBar();
        menuBar.add(captureMenu);

        setJMenuBar(menuBar);
    }

    private void initSystemMenu(final JxCaptureDemo demoApp) {
        Application application = Application.getApplication();
        application.setEnabledAboutMenu(true);
        application.setEnabledPreferencesMenu(true);
        application.addApplicationListener(new ApplicationAdapter() {
            public void handleAbout(ApplicationEvent event) {
                Actions.showAboutDialog();
                event.setHandled(true);
            }

            public void handlePreferences(ApplicationEvent event) {
                Actions.showSettingsDialog();
                event.setHandled(true);
            }

            public void handleQuit(ApplicationEvent event) {
                Actions.exit(demoApp);
                event.setHandled(true);
            }
        });
    }
}
