/*
 * Copyright (c) 2002-2008 TeamDev Ltd. All rights reserved.
 *
 * Use is subject to license terms.
 *
 * The complete licence text can be found at
 * http://www.teamdev.com/winpack/license.jsf
 */
package teamdev.jxcapture.samples.demo;

import teamdev.jxdesktop.Keyboard;
import teamdev.jxdesktop.PlatformContext;

import javax.swing.*;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.List;

/**
 * @author Ikryanov Vladimir
 */
public abstract class JxCaptureDemo implements Runnable {
    private Keyboard keyboard;
    private KeyListener keyListener;
    private ApplicationSettings settings;

    protected JxCaptureDemo() {
        keyListener = new KeyListener();
        settings = ApplicationSettings.getInstance();
    }

    protected abstract void createGUI();

    protected abstract void disposeGUI();

    public void run() {
        settings.loadSettings();
        keyboard = Keyboard.createKeyboard();
        keyboard.addKeyListener(keyListener);
        createGUI();
    }

    public void close() {
        if (canExit()) {
            settings.saveSettings();
            keyboard.removeKeyListener(keyListener);
            keyboard.dispose();
            disposeGUI();
            System.exit(0);
        }
    }

    private boolean canExit() {
        List activeViewers = CaptureOperations.getInstance().getActiveViewers();
        for (int i = 0; i < activeViewers.size(); i++) {
            ImageViewer activeViewer = (ImageViewer) activeViewers.get(i);
            if (!activeViewer.close()) {
                return false;
            }
        }
        return true;
    }

    private class KeyListener extends KeyAdapter {
        private CaptureOperations operations = CaptureOperations.getInstance();

        public void keyPressed(KeyEvent e) {
            if (e.isControlDown() && e.isShiftDown() && !operations.isBusy()) {
                switch (e.getKeyCode()) {
                    case KeyEvent.VK_A:
                        operations.activeWindowCapture();
                        break;
                    case KeyEvent.VK_W:
                        operations.objectCapture();
                        break;
                    case KeyEvent.VK_R:
                        operations.regionCapture();
                        break;
                    case KeyEvent.VK_F:
                        operations.desktopCapture();
                }
            }
        }
    }

    static {
        if (PlatformContext.isMacOS()) {
            System.setProperty("com.apple.mrj.application.apple.menu.about.name", "JxCapture Demo");
            System.setProperty("javax.swing.adjustPopupLocationToFit", "false");
            System.setProperty("apple.laf.useScreenMenuBar", "true");
            System.setProperty("com.apple.macos.useScreenMenuBar", "true");
            // <property name="apple.laf.useScreenMenuBar" value="true"/>
        }
    }

    public static void main(String[] args) throws Exception {
        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        if (PlatformContext.isWindows()) {
            SwingUtilities.invokeLater(new Win32JxCaptureDemo());
        } else if (PlatformContext.isMacOS()) {
            SwingUtilities.invokeLater(new MacOSJxCaptureDemo());
        }
    }
}
